==================
Python measurement
==================

**High precision unit-aware measurement objects in Python.**

.. code-block:: python

    >>> from measurement import measures
    >>> measures.Distance("12 megaparsec")["British yard"]
    Decimal('404948208659679393828910.8771')

This package provides a large reference collection of various measure and
their corresponding SI (Metric), US or Imperial units. Its high precision
supports use cases all the way from quantum mechanics to astrophysics.

- Documentation for python-measurement is available an
  `ReadTheDocs <https://python-measurement.readthedocs.org/>`_.
- Please post issues on
  `Github <https://github.com/coddingtonbear/python-measurement/issues>`_.
